/* ScianMethods.h
	function definitions for method wrappers.
*/

#ifdef PROTO
int SetValue(ObjPtr, ObjPtr);
ObjPtr GetValue(ObjPtr);
int ChangedValue(ObjPtr);
int ChangedPalette(ObjPtr);
int RecalcScroll(ObjPtr);
int ButtonPressed(ObjPtr);
int Mark(ObjPtr);
int AutoScroll(ObjPtr);
#else
int SetValue();
ObjPtr GetValue();
int ChangedValue();
int ChangedPalette();
int RecalcScroll();
int ButtonPressed();
int Mark();
int AutoScroll();
#endif
